# arpes.plotting.spin module

**arpes.plotting.spin.spin\_polarized\_spectrum(spin\_dr, title=None,
ax=None, out=None, component='y', scatter=False, stats=False,
norm=None)**

**arpes.plotting.spin.spin\_colored\_spectrum(spin\_dr, title=None,
ax=None, out=None, scatter=False,**kwargs)\*\*

**arpes.plotting.spin.spin\_difference\_spectrum(spin\_dr, title=None,
ax=None, out=None, scatter=False,**kwargs)\*\*
